@@ -7,8 +7,6 @@ from matplotlib import rcParams
 
 
 def get_plot_params(plot_params, show_score_diffs, diff):
-    pos_index = 1 if diff >= 0 else 0
-    neg_index = 0 if diff >= 0 else 1
     defaults = {
         "all_pos_contributions": False,
         "alpha_fade": 0.35,
@@ -21,6 +19,7 @@ def get_plot_params(plot_params, show_score_diffs, diff):
         "cumulative_ylabel": None,
         "detailed": True,
         "dpi": 200,
+        "every_nth_ytick": 5,
         "height": 15,
         "invisible_spines": [],
         "label_fontsize": 13,
@@ -45,19 +44,6 @@ def get_plot_params(plot_params, show_score_diffs, diff):
         "serif": False,
         "show_score_diffs": show_score_diffs,
         "show_total": True,
-        "symbols": {
-            "all_pos_neg": plot_params["system_names"][0],
-            "all_pos_pos": plot_params["system_names"][1],
-            "neg_s": u"\u25BD",
-            "neg_s_neg_p": u"-\u2193",
-            "neg_s_pos_p": u"-\u2191",
-            "neg_total": plot_params["system_names"][neg_index],
-            "pos_s": u"\u25B3",
-            "pos_s_neg_p": u"+\u2193",
-            "pos_s_pos_p": u"+\u2191",
-            "pos_total": plot_params["system_names"][pos_index],
-            "total": r"$\Sigma$",
-        },
         "system_names": ["Sys. 1", "Sys. 2"],
         "tick_format": "{:.1f}",
         "tight": True,
@@ -72,6 +58,19 @@ def get_plot_params(plot_params, show_score_diffs, diff):
         "ylabel_fontsize": 20,
         "ytick_fontsize": 14,
     }
+    defaults["symbols"] = {
+        "all_pos_neg": defaults["system_names"][0],
+        "all_pos_pos": defaults["system_names"][1],
+        "neg_s": u"\u25BD",
+        "neg_s_neg_p": u"-\u2193",
+        "neg_s_pos_p": u"-\u2191",
+        "neg_total": "",
+        "pos_s": u"\u25B3",
+        "pos_s_neg_p": u"+\u2193",
+        "pos_s_pos_p": u"+\u2191",
+        "pos_total": "",
+        "total": r"$\Sigma$",
+    }
     defaults.update(plot_params)
     return defaults
 
@@ -604,8 +603,9 @@ def set_ticks(ax, top_n, plot_params):
         x_ticks = [tick_format.format(abs(t)) for t in ax.get_xticks()]
     ax.set_xticklabels(x_ticks, fontsize=plot_params["xtick_fontsize"])
     # Flip y-axis tick labels and make sure every 5th tick is labeled
-    y_ticks = list(range(1, top_n, 5)) + [top_n]
-    y_tick_labels = [str(n) for n in (list(range(top_n, 1, -5)) + ["1"])]
+    y_ticks = list(range(1, top_n, plot_params["every_nth_ytick"])) + [top_n]
+    y_tick_label_pos = (list(range(top_n, 1, -plot_params["every_nth_ytick"])) + ["1"])
+    y_tick_labels = [str(n) for n in y_tick_label_pos]
     ax.set_yticks(y_ticks)
     ax.set_yticklabels(y_tick_labels, fontsize=plot_params["ytick_fontsize"])
 
@@ -714,7 +714,7 @@ def get_cumulative_inset(f, type2shift_score, top_n, normalization, plot_params)
     in_ax.semilogy(
         cum_scores,
         range(1, len(cum_scores) + 1),
-        "-o",
+        "-",
         color="black",
         linewidth=0.5,
         markersize=1.2,
